==> vivainsights_0.6.1.tar.gz: vivainsights/R/globals.R <==
# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

###################################################################

## Global Variables

## This file is added to minimize the false positives flagged during R CMD check.
## Example: afterhours_trend: no visible binding for global variable 'Date'

###################################################################

utils::globalVariables(
  c(
    "PersonId",
    ".",
    "group",
    "Employee_Count",
    "PANEL",
    "y",
    "x",
    "bucket_hours",
    "Employees",
    "heat_colours",
    "xmin",
    "xmax",
    "Date",
    "MetricDate", # New `Date`
    "top_group",
    "OrgGroup",
    "var1",
    "var2",
    "Total",
    "Metric",
    "Value",
    "Start",
    "End",
    "Group",
    "value",
    "where", # in `jitter_metrics()` for tidyselect
    "Hours",
    "Collaboration_hours",
    "External_collaboration_hours",
    "attribute",
    "values",
    "calculation",
    "variable",
    "value_rescaled",
    "Meeting_and_call_hours_with_manager_1_1",
    "Meetings_and_calls_with_manager_1_on_1",
    "Cadence_of_1_on_1_meetings_and_calls_with_manager",
    "Organization",
    "flag_nkw",
    "holidayweek",
    "mean_collab",
    "perc",
    "perc_nkw",
    "total",
    "ymax",
    "ymin",
    "z_score",
    ".N",
    "After_hours_collaboration_hours",
    "Attributes",
    "CH_ratio",
    "Collaboration_hrs",
    "HRAttribute",
    "Unique values",
    "WorkingEndTimeSetInOutlook",
    "name",
    "Email_hours",
    "Instant_message_hours",
    "values",
    "WorkingStartTimeSetInOutlook",
    "output_list",
    "Email_ratio",
    "PersonCount",
    "WorkdayFlag",
    "WorkdayRange",
    "identifier",
    "pre_group",
    "Emails_sent",
    "Shifts",
    "WorkdayFlag1",
    "subject_validate",
    "FirstValue",
    "TenureYear",
    "WorkdayFlag2",
    "tenure_years",
    "N",
    "V1",
    "V2",
    "Subject",
    "line",
    "text",
    "word",
    "freq",
    "PrimaryCollaborator_PersonId",
    "PrimaryOrg",
    "SecondaryCollaborator_PersonId",
    "SecondaryOrg",
    "betweenness",
    "closeness",
    "cluster",
    "colour",
    "degree",
    "eigenvector",
    "from",
    "metric_prop",
    "node_size",
    "org_size",
    "pagerank",
    "to",
    "Variable",
    "pval",
    "WOE",
    "ODDS",
    "labelpos",
    "cum_population",
    "cum_values",
    "cum_values_prop",
    "GainedHabit",
    "HabitCurve",
    "IsHabit",
    "LostHabit",
    "Most recent week - Total persons with habit",
    "Total Person-weeks",
    "Total Person-weeks with habit",
    "cumsum_value",
    "lagged_cumsum",
    "sum_last_w",
    "Period",
     "Y",
     "label",
     "IsHabit12w",
     "IsHabit4w",
     "prop",
     "target_metric"
    )
)

==> vivainsights_0.7.0.tar.gz: vivainsights/R/globals.R <==
# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

###################################################################

## Global Variables

## This file is added to minimize the false positives flagged during R CMD check.
## Example: afterhours_trend: no visible binding for global variable 'Date'

###################################################################

utils::globalVariables(
  c(
    "PersonId",
    ".",
    "group",
    "Employee_Count",
    "PANEL",
    "y",
    "x",
    "bucket_hours",
    "Employees",
    "heat_colours",
    "xmin",
    "xmax",
    "Date",
    "MetricDate", # New `Date`
    "top_group",
    "OrgGroup",
    "var1",
    "var2",
    "Total",
    "Metric",
    "Value",
    "Start",
    "End",
    "Group",
    "value",
    "where", # in `jitter_metrics()` for tidyselect
    "Hours",
    "Collaboration_hours",
    "External_collaboration_hours",
    "attribute",
    "values",
    "calculation",
    "variable",
    "value_rescaled",
    "Meeting_and_call_hours_with_manager_1_1",
    "Meetings_and_calls_with_manager_1_on_1",
    "Cadence_of_1_on_1_meetings_and_calls_with_manager",
    "Organization",
    "flag_nkw",
    "holidayweek",
    "mean_collab",
    "perc",
    "perc_nkw",
    "pct",
    "total",
    "ymax",
    "ymin",
    "z_score",
    ".N",
    "After_hours_collaboration_hours",
    "Attributes",
    "CH_ratio",
    "Collaboration_hrs",
    "HRAttribute",
    "Unique values",
    "WorkingEndTimeSetInOutlook",
    "name",
    "Email_hours",
    "Instant_message_hours",
    "values",
    "WorkingStartTimeSetInOutlook",
    "output_list",
    "Email_ratio",
    "PersonCount",
    "WorkdayFlag",
    "WorkdayRange",
    "identifier",
    "pre_group",
    "Emails_sent",
    "Shifts",
    "WorkdayFlag1",
    "subject_validate",
    "FirstValue",
    "TenureYear",
    "WorkdayFlag2",
    "tenure_years",
    "N",
    "V1",
    "V2",
    "Subject",
    "line",
    "text",
    "word",
    "freq",
    "PrimaryCollaborator_PersonId",
    "PrimaryOrg",
    "SecondaryCollaborator_PersonId",
    "SecondaryOrg",
    "betweenness",
    "closeness",
    "cluster",
    "colour",
    "degree",
    "eigenvector",
    "from",
    "metric_prop",
    "node_size",
    "org_size",
    "pagerank",
    "to",
    "Variable",
    "pval",
    "WOE",
    "ODDS",
    "labelpos",
    "cum_population",
    "cum_values",
    "cum_values_prop",
    "GainedHabit",
    "HabitCurve",
    "IsHabit",
    "LostHabit",
    "Most recent week - Total persons with habit",
    "Total Person-weeks",
    "Total Person-weeks with habit",
    "cumsum_value",
    "lagged_cumsum",
    "sum_last_w",
     "Period",
     "Y",
     "label",
     "IsHabit12w",
     "IsHabit4w",
     "prop",
     "target_metric",
     "adoption_week",
     "cumulative_adopters",
     "cumulative_percent",
     "new_adopters",
     "moving_avg",
     "enable_week",
     "weeks_to_adopt",
     "adoption_delay_percent",
     "RogersSegment_delay",
     "cumulative",
     "earliest_adoption",
     "latest_adoption",
     "median_adoption_week",
     "total_adopters"
    )
)
